@@ -14,10 +14,8 @@ has 'ua' => (
 );
 
 sub resolve {
-    my ( $self, $module, $ignore_reslovement_modules ) = @_;
-    return $module if $module eq 'perl';
-    return $module if $module eq 'PerlInterp';
-    # return if any { $module eq $_ } @{ $ignore_reslovement_modules || [] };
+    my ( $self, $module  ) = @_;
+    return $module if any { $module eq $_} ('perl', 'PerlInterp');
 
     my $res = $self->get_or_retry(
         "http://search.cpan.org/search?query=$module&mode=module");
@@ -41,3 +39,26 @@ sub get_or_retry {
 
 __PACKAGE__->meta->make_immutable;
 1;
+
+=head1 NAME
+
+CPAN::Packager::ModuleNameResolver - resolve CPAN module name
+
+=head1 SYNOPSIS
+
+
+=head1 DESCRIPTION
+
+
+=head1 AUTHOR
+
+Takatoshi Kitano E<lt>kitano.tk@gmail.comE<gt>
+
+=head1 SEE ALSO
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
